Starting a Photography Business: A How-to Guide
Description: Starting a Photography Business: How to combine business and pleasure for maximum income by selling your images.
Keywords: starting a photography business,making money with photograhy

## basic-photography-tips.com

Menu

- Home
- Share your Tips!
- Welcome
  - About Me
  - What's New?
  - Build a Website
  - Build a Business
- Community
  - Pic of the Day
  - Your Best Shot
  - How-to Videos
  - Masterclass
- Photography Basics
  - Beginners Tips
  - Composition Tips
- Digital Skills
  - Basics Made Easy
  - Digital Tips
  - Digital Tutorials
  - Video Tutorials
  - Troubleshooting
- Digital Darkroom
  - Image Editing
- Portraiture
  - Portraits
  - Children
  - Families
  - Females
  - Sensual
- Top Tips
  - Top 50 Tips
  - Photography
  - Light
  - Stock Photos
  - Black and White
  - Landscapes
  - Travel
  - Macro
  - Weddings
  - Sports
  - Wildlife
  - Still Life
  - Flowers
  - Underwater
  - Food
  - Automotive
  - Abstract
  - Photographers
  - How to's
- Camera Reviews
  - Buyer's Guide
  - Camera Types
  - DSLR Reviews
  - Compact Reviews
- Photo Projects
  - 365 Project
  - Color Palette
- Resources
  - Helpdesk
  - Photo Sharing
  - Photo Galleries

# Starting a Photography Business

Thinking of starting a photography business? There's nothing more satisfying than making money from something that you love to do.

## First Steps to Making Money with Photography

1. Master your camera and the basics of photography. Learn all you can about composition and lighting. One of the most important aspects of starting a photography business is to gain experience shooting a variety of subjects.

2. Decide what genres you want to work with (for example weddings, portraits, pets, or architecture), then focus your learning on developing skills specific to those genres. There are plenty of excellent books and courses that will provide the theory, then it's up to you to practice, practice, practice!

© Mia Rose

3. Be a student of your local market. If you're in an area that is over-saturated with photographers, you won't succeed unless you are markedly different or have something unique to offer.

4. Do your research when it comes to pricing your services and products. Look at several other photography businesses / websites in your state and price comparatively. You don't want to overprice, but you certainly don't want to undersell yourself either.

5. Consider starting part-time while still generating an income from your regular job. That takes a lot of pressure off you in the beginning stages of establishing your photography business.

6. Learn the 'business' side of photography. One of the first things you need to do is talk to an accountant. Many great photographers lack business sense, and it hampers their ability to earn a living doing what they love. A good accountant can give you advice on how to set up your business and keep you on track with finances. Remember, the first rule of business is to earn more than you spend! You'll need a good bit of discipline. Also keep in mind that when you open your door for business, your focus will very quickly shift from 'photographer' to 'entrepreneur' - be prepared to deal with that! In the end, succeeding has as much to do with being a smart business person than making great photographs.

7. Consult an attorney to make sure you're in conformation with all applicable laws and regulations.

8. Present yourself as a professional. This includes using a good lab to provide quality prints to your clients.

9. Watch how you manage your time! First, there will be great demands on your time from both the business side and the production side. Especially in the beginning, it can be difficult to decide what things are worth spending time on. For example, you will have to do advertising, marketing, and sales. It's a challenge to figure out how to divide up your time (and cash) for these activities.

Here's a rule of thumb: If the task has revenue directly associated with it, you know that the more you do, the more revenue you will have. But much of what has to happen, especially in the beginning, feels like you're just spinning your wheels. A good tip is to keep a project folder and time sheet for your photo projects. This will help you to work out whether you're charging enough to cover both your time and materials.

Experience has taught that in starting a photography business, there is no magic formula. You have to be creative - both in your photography and in your business. Work out what fits your style best, work hard, practice persistence... and the money will follow for sure.

My gratitude goes to Sean and Nathan McCreery for their helpful comments on the PictureSocial Network for Photographers while I was doing research for this article.

## Feedback

Do you have Feedback or Suggestions you'd like to share?

Enter Your Title

Enter your Feedback [ ? ]

Close Help Just type!...

Upload 1-4 Pictures or Graphics (optional)[ ? ]

Close Help Do you have an image to add? Great! Click the button and find it on your computer. Then select it.

Add a Picture/Graphic Caption (optional)

Click here to upload more images (optional)

Add a Picture/Graphic Caption (optional)

Add a Picture/Graphic Caption (optional)

Add a Picture/Graphic Caption (optional)

Author Information (optional)

To receive credit as the author, enter your information below.

Your Name | (first or full name)
Your Location | (e.g., City, State, Country)

Submit Your Contribution

Check box to agree to these submission guidelines.

(You can preview and edit on the next page)

## What Other Visitors Have Said

Click below to see contributions from other visitors to this page...

Starting a Photography Business: Stock Photos
Reader Post: Starting a photography business is both easier and more difficult than what people might think. I bought a stock-photography course with stars …

Architectural Photography
I've been trying to build a business as an Architectural Photographer and the biggest hurdle I've come up against is reputation (or lack there of). I think …

Excellent Advice
This is excellent advice, Mia... Personally I've found that marketing is one of the big stumbling blocks for me in my own business. I'm good at photography, …

Click here to write your own.

If you found this page on starting a photography business useful, make sure to visit the following pages as well:

- Making Money with Photography
- Creating a Photography Business Plan
- Market your Photography Business
- Building a Photography Website
- Stock Photography Tips

(From Starting a Photography Business back to Basic Photography Tips Home)

Read, reflect and be inspired. If you find something of value here, enjoy its gifts and please pass it on to your friends.